/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit } from '@angular/core';
import { CapabilityRequest } from '../../model/capability-request';
import { CapabilityRequestService } from '../../services/capability-request.service';

@Component({
  selector: 'app-analyst-tools',
  templateUrl: './analyst-tools.component.html',
  styleUrls: ['./analyst-tools.component.scss'],
})
export class AnalystToolsComponent implements OnInit {
  // tslint:disable-next-line:variable-name
  public capability_name = '';
  public activeCapabilityRequests: Array<CapabilityRequest>;

  constructor(private capabilityRequestService: CapabilityRequestService) {}

  ngOnInit(): void {
  }

  setCapability(name: string) {
    this.capability_name = name;
  }

  getCapability() {
    return this.capability_name;
  }

  getActiveRequests(capabilityName: string) {
    const activeCapabilityRequestsObserver = {
      next: (request) => {
        this.activeCapabilityRequests = request.active_requests;
      },
      error: (error) => console.error("Error when retrieving list of active capability requests:" + error),
    };
    this.capabilityRequestService.getActiveCapabilityRequests(capabilityName).subscribe(activeCapabilityRequestsObserver);
  }
}
